PCB Environment: Color Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions | Static Public Attributes
Color Class Reference

## Public Member Functions
| Color (std::string_view)
constexpr | Color (uint32_t abgr)
constexpr | Color (uint8_t R, uint8_t G, uint8_t B, uint8_t A=255)
uint32_t | ABGR8 () const
Color & | operator= (const Color &c)
bool | operator== (const Color &c) const
bool | isVisible () const
void | getFloat4 (float *) const
Color | withAlpha (float a) const
std::string | str () const

## Static Public Member Functions
static Color | HSV (int h, float s, float v, float a=1.0f)
static Color | RGBA (float r, float g, float b, float a)

## Static Public Attributes
static const Color | TRANSPARENT
static const Color | BLACK
static const Color | WHITE
static const Color | RED
static const Color | GREEN
static const Color | BLUE
static const Color | CYAN
static const Color | MAGENTA
static const Color | YELLOW
static const Color | ORANGE
static const Color | PINK
static const Color | POISON
static const Color | MINT
static const Color | SKY

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Color.hpp